@@ -4,6 +4,7 @@
 $perpage='50';
 require_once('../inc/conn.inc.php');
 require_once('../sqlsend.php');
+require_once("../excel_class.php");
 //require_once('../inc/conn.php');
 /*
 if(!isset($_COOKIE['username'])) {
@@ -215,5 +216,35 @@ function WriteSuccessMsg($SuccessMsg,$URL)
 	exit;
 }
 
+function export_sim($where, $orderby)
+{
+	global $db;
+	$query=$db->query("SELECT sim.* FROM sim  $where $orderby");
+	//echo "SELECT sim.* FROM sim  $where $orderby";
+	$filename="SIM_".date("YmdHim").".xls";
+
+	$return[0][0]="Slot ID";
+	$return[0][1]="ONLINE";
+	$return[0][2]="IMSI";
+	$return[0][3]="ICCID";
+	$return[0][4]="NUMBER";
+
+	$i=1;
+	while($rs=$db->fetch_array($query)) {
+		if($rs['sim_login'] == 0 || $rs['sim_login'] == 12){
+			$rs['alive']=0;
+		}else $rs['alive']=1;
+		$rs['imsi']=str_replace('"','',$rs['imsi']);
+		$rs['iccid']=str_replace(' ','',$rs['iccid']);
+		$return[$i][0]="".$rs['sim_name'];
+		$return[$i][1]="".$rs['alive'];
+		$return[$i][2]="".$rs['imsi'];
+		$return[$i][3]="".$rs['iccid'];
+		$return[$i][4]="".$rs['simnum'];
+		$i++;
+	}
+	Create_Excel_File($filename,$return);
+	//exit;
+}
 
 ?>
